Index: trunk/tools/eam/rawfix.20230221/Makefile
===================================================================
--- trunk/tools/eam/rawfix.20230221/Makefile	(revision 42453)
+++ trunk/tools/eam/rawfix.20230221/Makefile	(revision 42454)
@@ -5,18 +5,4 @@
 BIN	=	~/src/bin/rawfix
 SRC	= 	src
-
-install: $(PROGRAMS)
-
-$(PROGRAMS): % : $(BIN)/%
-
-# copied from Makefile.Common : use a single c file: foo : foo.c
-.PRECIOUS: $(BIN)/%
-
-$(BIN)/% : $(SRC)/%
-	@if [ ! -d $(BIN) ]; then mkdir -p $(BIN); fi
-	rm -f $(BIN)/$*
-	cp $(SRC)/$* $(BIN)/$*
-
-PROGRAMS = $(PANTASKS) $(DB_PROG) $(PERL_PROG) $(TOOLS)
 
 PANTASKS = \
@@ -58,2 +44,14 @@
 fix_chip_failures.pl \
 
+PROGRAMS = $(PANTASKS) $(DB_PROG) $(PERL_PROG) $(TOOLS)
+
+install: $(PROGRAMS)
+
+$(PROGRAMS): % : $(BIN)/%
+
+$(BIN)/% : $(SRC)/%
+	@if [ ! -d $(BIN) ]; then mkdir -p $(BIN); fi
+	rm -f $(BIN)/$*
+	cp $(SRC)/$* $(BIN)/$*
+
+
Index: trunk/tools/eam/rawfix.20230221/src/check.rawfix.sh
===================================================================
--- trunk/tools/eam/rawfix.20230221/src/check.rawfix.sh	(revision 42453)
+++ trunk/tools/eam/rawfix.20230221/src/check.rawfix.sh	(revision 42454)
@@ -14,5 +14,5 @@
 
 # make the rawfix database to track rawfix operations
-set DBHOST = "ipp060"
+set DBHOST = "ippc190"
 set DBNAME = "rawfix"
 set DBUSER = "dvo"
Index: trunk/tools/eam/rawfix.20230221/src/queue.rawfix.sh
===================================================================
--- trunk/tools/eam/rawfix.20230221/src/queue.rawfix.sh	(revision 42453)
+++ trunk/tools/eam/rawfix.20230221/src/queue.rawfix.sh	(revision 42454)
@@ -10,5 +10,5 @@
 
 # make the rawfix database to track rawfix operations
-set DBHOST = "ipp060"
+set DBHOST = "ippc190"
 set DBNAME = "rawfix"
 set DBUSER = "dvo"
Index: trunk/tools/eam/rawfix.20230221/src/rawfix.advance.pt
===================================================================
--- trunk/tools/eam/rawfix.20230221/src/rawfix.advance.pt	(revision 42453)
+++ trunk/tools/eam/rawfix.20230221/src/rawfix.advance.pt	(revision 42454)
@@ -17,5 +17,4 @@
 
   task.exec
-    # 
     command advance.rawfix.pl --mode all --topdir $mypath --Nmax $MAX_ACTIVE_NIGHTS
   end
Index: trunk/tools/eam/rawfix.20230221/src/rawfix.ckchip.pt
===================================================================
--- trunk/tools/eam/rawfix.20230221/src/rawfix.ckchip.pt	(revision 42453)
+++ trunk/tools/eam/rawfix.20230221/src/rawfix.ckchip.pt	(revision 42454)
@@ -90,5 +90,5 @@
 
     # this command accesses the Nebulous and GPC databases, so it must run at ITC.
-    command $mypath/check_chip_locations.pl --topdir $mypath --dateobs $FULLDATE --chiplist gpc1.chips.txt --stage $ITER
+    command check_chip_locations.pl --topdir $mypath --dateobs $FULLDATE --chiplist gpc1.chips.txt --stage $ITER
   end
 
Index: trunk/tools/eam/rawfix.20230221/src/rawfix.fixchip.pt
===================================================================
--- trunk/tools/eam/rawfix.20230221/src/rawfix.fixchip.pt	(revision 42453)
+++ trunk/tools/eam/rawfix.20230221/src/rawfix.fixchip.pt	(revision 42454)
@@ -93,5 +93,5 @@
     # the command returns these fields: dateobs stage fixhost chipID
     # NOTE: stage == ITER
-    command $mypath/get_hosts_fixchip.sh $mypath $DATEOBS $ITER
+    command get_hosts_fixchip.sh $mypath $DATEOBS $ITER
   end
 
@@ -172,5 +172,5 @@
     # if we are able to run the 'exec', use a short retry time to launch all outstanding jobs
     periods -exec 0.05
-    command $mypath/fix_chip_locations.pl --topdir $mypath --dateobs $FULLDATE --chiplist gpc1.chips.txt --chipID $CHIP_ID --stage $ITER
+    command fix_chip_locations.pl --topdir $mypath --dateobs $FULLDATE --chiplist gpc1.chips.txt --chipID $CHIP_ID --stage $ITER
   end
 
Index: trunk/tools/eam/rawfix.20230221/src/rawfix.md5chk.pt
===================================================================
--- trunk/tools/eam/rawfix.20230221/src/rawfix.md5chk.pt	(revision 42453)
+++ trunk/tools/eam/rawfix.20230221/src/rawfix.md5chk.pt	(revision 42454)
@@ -86,5 +86,5 @@
 
     ## this command does NOT use Nebulous or GPC so it can run anywhere
-    command $mypath/check_md5s_dateobs.pl --topdir $mypath --dateobs $FULLDATE --stage $ITER
+    command check_md5s_dateobs.pl --topdir $mypath --dateobs $FULLDATE --stage $ITER
   end
 
Index: trunk/tools/eam/rawfix.20230221/src/rawfix.md5sum.pt
===================================================================
--- trunk/tools/eam/rawfix.20230221/src/rawfix.md5sum.pt	(revision 42453)
+++ trunk/tools/eam/rawfix.20230221/src/rawfix.md5sum.pt	(revision 42454)
@@ -93,5 +93,5 @@
     # the command returns these fields: dateobs stage md5host
     # NOTE: stage == ITER
-    command $mypath/get_hosts_md5s.sh $mypath $DATEOBS $ITER
+    command get_hosts_md5s.sh $mypath $DATEOBS $ITER
   end
 
@@ -160,5 +160,4 @@
     stderr $mypath/$DATEOBS/log.md5sum.runhosts.v$ITER  
 
-    # XXX TEST: $USE_HOST = ipp060
     $USE_HOST = $MD5HOST
     host -required $USE_HOST
@@ -179,6 +178,5 @@
     # if we are able to run the 'exec', use a short retry time to launch all outstanding jobs
     periods -exec 0.05
-    command $mypath/get_md5s_instances.pl --hostname $USE_HOST --topdir $mypath --dateobs $DATEOBS --stage $ITER
-#   command $mypath/get_md5s_instances.pl --hostname $USE_HOST --input $input --stage $ITER
+    command get_md5s_instances.pl --hostname $USE_HOST --topdir $mypath --dateobs $DATEOBS --stage $ITER
   end
 
Index: trunk/tools/eam/rawfix.20230221/src/update.rawfix.sh
===================================================================
--- trunk/tools/eam/rawfix.20230221/src/update.rawfix.sh	(revision 42453)
+++ trunk/tools/eam/rawfix.20230221/src/update.rawfix.sh	(revision 42454)
@@ -16,5 +16,5 @@
 
 # make the rawfix database to track rawfix operations
-set DBHOST = "ipp060"
+set DBHOST = "ippc190"
 set DBNAME = "rawfix"
 set DBUSER = "dvo"

Index: trunk/tools/eam/rawfix.20230221/src/get_hosts_fixchip.sh
===================================================================
--- trunk/tools/eam/rawfix.20230221/src/get_hosts_fixchip.sh	(revision 42453)
+++ trunk/tools/eam/rawfix.20230221/src/get_hosts_fixchip.sh	(revision 42454)
@@ -27,8 +27,8 @@
   set chipID = `echo $f | awk -F/ '{print $NF}' | awk -F. '{print $1}'`
   if ("$myhost" == "") then
-    set myhost = ipp060
+    set myhost = ipp156
   endif
   echo $dateobs $chipID $iter $myhost
 end
 
 ## XXX ipp060 is hardwired for no good reason
@@ -27,8 +27,8 @@
 end
 
-## XXX ipp060 is hardwired for no good reason
+## XXX ipp156 is hardwired for no good reason